@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2020 Michal Čihař <michal@cihar.com>
+# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate translation-finder
 # <https://github.com/WeblateOrg/translation-finder>
@@ -22,66 +22,15 @@
 import sys
 from argparse import ArgumentParser
 
-from .discovery.files import (
-    AndroidDiscovery,
-    AppStoreDiscovery,
-    ARBDiscovery,
-    ASSDiscovery,
-    CSVDiscovery,
-    FluentDiscovery,
-    GettextDiscovery,
-    HTMLDiscovery,
-    IDMLDiscovery,
-    INIDiscovery,
-    InnoSetupDiscovery,
-    JavaDiscovery,
-    JoomlaDiscovery,
-    JSONDiscovery,
-    ODFDiscovery,
-    OSXDiscovery,
-    PHPDiscovery,
-    QtDiscovery,
-    RESXDiscovery,
-    SRTDiscovery,
-    SSADiscovery,
-    SUBDiscovery,
-    TOMLDiscovery,
-    WebExtensionDiscovery,
-    XliffDiscovery,
-    YAMLDiscovery,
-)
-from .discovery.transifex import TransifexDiscovery
 from .finder import Finder
 
-BACKENDS = [
-    TransifexDiscovery,
-    AndroidDiscovery,
-    AppStoreDiscovery,
-    ARBDiscovery,
-    ASSDiscovery,
-    CSVDiscovery,
-    FluentDiscovery,
-    GettextDiscovery,
-    HTMLDiscovery,
-    IDMLDiscovery,
-    INIDiscovery,
-    InnoSetupDiscovery,
-    JavaDiscovery,
-    JoomlaDiscovery,
-    JSONDiscovery,
-    ODFDiscovery,
-    OSXDiscovery,
-    PHPDiscovery,
-    QtDiscovery,
-    RESXDiscovery,
-    SRTDiscovery,
-    SSADiscovery,
-    SUBDiscovery,
-    TOMLDiscovery,
-    WebExtensionDiscovery,
-    XliffDiscovery,
-    YAMLDiscovery,
-]
+BACKENDS = []
+
+
+def register_discovery(cls):
+    """Registers a discovery class."""
+    BACKENDS.append(cls)
+    return cls
 
 
 def discover(root, mock=None, source_language: str = "en", eager: bool = False):
